Computes estimation results for the MCMC sampling output for a specific HPDI and evaluation function (e.g. mean or median).
compute_mcmc_results(
model,
settings,
mcmc,
data,
HPDIprob = NULL,
fit = NULL,
...
)An object of class ss_fit.
state space model object, returned by the function
define_ssmodel
list with model setting, in the format returned by the
function initialize_settings
list with draws of parameters and states (including burnin phase)
list with at least two named components: tsm is a multiple
time series object that contains all observation series, weights
is a named list of time series with (nominal) weights, the list names
correspond to the different groups, i.e., group1, group2, subgroup1,
if present in the model
probability of highest posterior density interval, optional
if fit is supplied
(optional) an object of class fit (returned by the function
estimate_ssmodel and this function).
additional arguments (in case fit is supplied)
If fit is supplied, the arguments
model, settings, mcmc will be taken from this object.