| define_ssmodel | R Documentation |
Defines a state space model for the provided settings and data.
define_ssmodel(settings, data)
settings |
list with model setting, in the format returned by the
function |
data |
list with at least two named components: |
data is preferably the output of funtion prepare_data.
A state space model object of class ss_model, which consists
of an object returned by the function SSModel of
the package KFAS and in addition a list item called names
which contains information on the parameters to be estimated.
data("data_ch")
settings <- initialize_settings()
data <- prepate_data(
settings = settings,
tsl = data_ch$tsl,
tsl_n = data_ch$tsl_n
)
model <- define_ssmodel(
settings = settings,
data = data
)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.