| update_ssmodel | R Documentation |
Updates the system matrices of a state space model.
update_ssmodel(pars, model, model_last, settings, df_set)
pars |
named vector with all parameters |
model |
state space model object (unassigned) |
model_last |
state space model object (previous draw) |
settings |
list with model setting, in the format returned by the
function |
df_set |
data frame with model settings |
data is preferably the output of funtion prepare_data.
The state space model object model with updates matrices.
data("data_ch")
settings <- initialize_settings()
data <- prepate_data(
settings = settings,
tsl = data_ch$tsl,
tsl_n = data_ch$tsl_n
)
model <- define_ssmodel(
settings = settings,
data = data
)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.